try:
    # python2
    from HTMLParser import HTMLParser
except ImportError:
    # python3
    from html.parser import HTMLParser


class HTML2BBCode(HTMLParser):
    """
    HTML to BBCode converter

    >>> parser = HTML2BBCode()
    >>> str(parser.feed('<ul><li>one</li><li>two</li></ul>'))
    '[list][li]one[/li][li]two[/li][/list]'

    >>> str(parser.feed('<a href="http://google.com/">Google</a>'))
    '[url=http://google.com/]Google[/url]'

    >>> str(parser.feed('<img src="http://www.google.com/images/logo.png">'))
    '[img]http://www.google.com/images/logo.png[/img]'

    >>> str(parser.feed('<em>EM test</em>'))
    '[i]EM test[/i]'

    >>> str(parser.feed('<strong>Strong text</strong>'))
    '[b]Strong text[/b]'

    >>> str(parser.feed('<code>a = 10;</code>'))
    '[code]a = 10;[/code]'

    >>> str(parser.feed('<blockquote>Beautiful is better than ugly.</blockquote>'))
    '[quote]Beautiful is better than ugly.[/quote]'
    """
    def handle_starttag(self, tag, attrs):
        if tag == 'ul':
            self.data.append('[list]')
        elif tag == 'li':
            self.data.append('[li]')
        elif tag == 'a':
            attrs = dict(attrs)
            self.data.append('[url=%s]' % attrs.get('href'))
        elif tag == 'img':
            attrs = dict(attrs)
            self.data.append('[img]%s[/img]' % attrs.get('src'))
        elif tag == 'em':
            self.data.append('[i]')
        elif tag == 'strong':
            self.data.append('[b]')
        elif tag == 'code':
            self.data.append('[code]')
        elif tag == 'blockquote':
            self.data.append('[quote]')

    def handle_endtag(self, tag):
        if tag == 'ul':
            self.data.append('[/list]')
        elif tag == 'li':
            self.data.append('[/li]')
        elif tag == 'a':
            self.data.append('[/url]')
        elif tag == 'em':
            self.data.append('[/i]')
        elif tag == 'strong':
            self.data.append('[/b]')
        elif tag == 'code':
            self.data.append('[/code]')
        elif tag == 'blockquote':
            self.data.append('[/quote]')

    def handle_data(self, data):
        self.data.append(data)

    def feed(self, data):
        self.data = []
        HTMLParser.feed(self, data)
        return u''.join(self.data)

if __name__=='__main__':
    import doctest
    doctest.testmod()
